@@ -6,7 +6,7 @@ require Exporter;
 @EXPORT = qw(wrap fill);
 @EXPORT_OK = qw($columns $break $huge);
 
-$VERSION = 2005.0824;
+$VERSION = 2006.0705;
 
 use vars qw($VERSION $columns $debug $break $huge $unexpand $tabstop
 	$separator $separator2);
@@ -44,7 +44,7 @@ sub wrap
 
 	pos($t) = 0;
 	while ($t !~ /\G\s*\Z/gc) {
-		if ($t =~ /\G([^\n]{0,$ll})($break|\z)/xmgc) {
+		if ($t =~ /\G([^\n]{0,$ll})($break|\n*\z)/xmgc) {
 			$r .= $unexpand 
 				? unexpand($nl . $lead . $1)
 				: $nl . $lead . $1;
@@ -61,6 +61,10 @@ sub wrap
 			$remainder = $2;
 		} elsif ($huge eq 'die') {
 			die "couldn't wrap '$t'";
+		} elsif ($columns < 2) {
+			warn "Increasing \$Text::Wrap::columns from $columns to 2";
+			$columns = 2;
+			return ($ip, $xp, @t);
 		} else {
 			die "This shouldn't happen";
 		}
@@ -125,7 +129,7 @@ B<Example 1>
 	print wrap($initial_tab, $subsequent_tab, @text);
 	print fill($initial_tab, $subsequent_tab, @text);
 
-	@lines = wrap($initial_tab, $subsequent_tab, @text);
+	$lines = wrap($initial_tab, $subsequent_tab, @text);
 
 	@paragraphs = fill($initial_tab, $subsequent_tab, @text);
 
@@ -148,11 +152,11 @@ B<Example 3>
 =head1 DESCRIPTION
 
 C<Text::Wrap::wrap()> is a very simple paragraph formatter.  It formats a
-single paragraph at a time by breaking lines at word boundries.
+single paragraph at a time by breaking lines at word boundaries.
 Indentation is controlled for the first line (C<$initial_tab>) and
 all subsequent lines (C<$subsequent_tab>) independently.  Please note: 
 C<$initial_tab> and C<$subsequent_tab> are the literal strings that will
-be used: it is unlikley you would want to pass in a number.
+be used: it is unlikely you would want to pass in a number.
 
 Text::Wrap::fill() is a simple multi-paragraph formatter.  It formats
 each paragraph separately and then joins them together when it's done.  It
@@ -160,6 +164,8 @@ will destroy any whitespace in the original text.  It breaks text into
 paragraphs by looking for whitespace after a newline.  In other respects
 it acts like wrap().
 
+Both C<wrap()> and C<fill()> return a single string.
+
 =head1 OVERRIDES
 
 C<Text::Wrap::wrap()> has a number of variables that control its behavior.
@@ -208,15 +214,35 @@ left intact.
 Historical notes: 'die' used to be the default value of
 C<$huge>.  Now, 'wrap' is the default value.
 
-=head1 EXAMPLE
+=head1 EXAMPLES
 
-	print wrap("\t","","This is a bit of text that forms 
-		a normal book-style paragraph");
+Code:
+
+  print wrap("\t","",<<END);
+  This is a bit of text that forms 
+  a normal book-style indented paragraph
+  END
+
+Result:
+
+  "	This is a bit of text that forms
+  a normal book-style indented paragraph   
+  "
+
+Code:
+
+  $Text::Wrap::columns=20;
+  $Text::Wrap::separator="|";
+  print wrap("","","This is a bit of text that forms a normal book-style paragraph");
+
+Result:
+
+  "This is a bit of|text that forms a|normal book-style|paragraph"
 
 =head1 LICENSE
 
 David Muir Sharnoff <muir@idiom.com> with help from Tim Pierce and
-many many others.  Copyright (C) 1996-2002 David Muir Sharnoff.  
+many many others.  Copyright (C) 1996-2006 David Muir Sharnoff.  
 This module may be modified, used, copied, and redistributed at
 your own risk.  Publicly redistributed modified versions must use 
 a different name.
